==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/ron/controls/options.php <==
<?php
/**
 * stanislav.elbl, 21.02.2021
 */

namespace Ron\Controls;

use Ron\DB\Database;
use Ron\DB\Parameters;
use Ron\DB\SqlStatement;

/**
 * Class Options
 * @package Ron\Controls
 * Seznam objektu (defaultne tridy Options, ale muze byt i jakakoliv jina)
 */
class Options
{
    /** @var string Jmeno pole objektu, ktere obsahuje kod - defaultne je to "key" */
    var $keyFieldName;
    /** @var string Jmeno pole objektu, ktere obsahuje popis - defaultne je to "value" */
    var $valueFieldName;

    /** @var Option[]|object[] $data   Pole hodnot */
    var $data;

    /** @var ICreateItem */
    var $createItemInterface = null;

    /**
     * @param {Option[]|string[]|object[]} $data  muze to byt pole objektu Option, nebo jinych objektu, nebo asociativni pole stringu
     * @param string $keyFieldName
     * @param string $valueFieldName
     */
    function __construct($data = null, $keyFieldName = 'key', $valueFieldName = 'value')
    {
        $this ->keyFieldName = $keyFieldName;
        $this ->valueFieldName = $valueFieldName;

        if (isset($data)) {
            if (count($data)  &&  !(is_object(reset($data)))) {
                $this ->data = [];
                $this ->loadArray($data);
            } else {
                $this ->data = $data;
            }
        } else {
            $this ->data = [];
        }
    }


    /**
     * @param string[] $array
     * @return Options
     */
    function loadArray($array)
    {
        foreach ($array as $key => $value) {
            $this ->data[] = new Option($key, $value);
        }

        return $this;
    }


    /**
     * @param Option|object $option
     */
    function addOption($option)
    {
        $this ->data[] = $option;
    }

    /**
     * Najde zadanou hodnotu v datech
     * @param mixed $key
     * @param bool $dataTypeComparison
     * @return null|Option
     */
    function findOption($key, $dataTypeComparison = true)
    {
        foreach ($this ->data as $option) {
            if ($key !== ''  &&  $option ->{$this ->keyFieldName} === '') {
                $equalValue = false;
            } else {
                $equalValue = $dataTypeComparison ? ($key === $option->{$this->keyFieldName}) : ($key == $option->{$this->keyFieldName});
            }

            if ($equalValue) {
                return $option;
            }
        }



        return null;
    }


    function addOptions($newOptions)
    {
        foreach ($newOptions as $item) {
            $this ->data[] = $item;
        }

        return $this;
    }

    /**
     * Nacte polozky ze zadaneho dotazu. Nezrusi polozky, ktere uz v seznamu jsou. Vraci $this
     * @param Database $database
     * @param string|SqlStatement $sql
     * @param Parameters $sqlParams
     * @param int $keyIndex         Index pole s klicem v sql dotazu
     * @param int $captionIndex     Index pole s hodnotou v sql dotazu
     * @param int $titleIndex
     * @param int $cssClassIndex
     * @param int[] $attrIndexes     Asociativni pole indexu poli, ktere se maji zapsat do params (jmeno parametru => index)
     * @param mixed[] $preferredValues  Pole "preferovanych" hodnot - nactou se na zacatek (mimo poradi z sql)
     * @return Options
     */
    function loadSQL($database, $sql, $sqlParams, $keyIndex = 0, $captionIndex = 1, $titleIndex = null, $cssClassIndex = null, $attrIndexes = null, $preferredValues = null)
    {
        $newData = Option::loadSQL($database, $sql, $sqlParams, $keyIndex, $captionIndex, null, $titleIndex, $cssClassIndex, $attrIndexes, $preferredValues);
        $this ->addOptions($newData);
        return $this;
    }


    /**
     * @param Database      $database
     * @param string|SqlStatement $sql
     * @param Parameters    $sqlParams
     * @param ICreateItem   $createItemInterface
     * @return array
     */
    function loadSQLCustomCreate($database, $sql, $sqlParams, $createItemInterface)
    {
        $newData = Option::loadSQLCustomCreate($database, $sql, $sqlParams, $createItemInterface);
        $this ->addOptions($newData);
        return $this;
    }
}

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2206_162.zip: ronportal/ron/controls/options.php <==
<?php
/**
 * stanislav.elbl, 21.02.2021
 */

namespace Ron\Controls;

use Ron\DB\Database;
use Ron\DB\Parameters;
use Ron\DB\SqlStatement;

/**
 * Class Options
 * @package Ron\Controls
 * Seznam objektu (defaultne tridy Options, ale muze byt i jakakoliv jina)
 */
class Options
{
    /** @var string Jmeno pole objektu, ktere obsahuje kod - defaultne je to "key" */
    var $keyFieldName;
    /** @var string Jmeno pole objektu, ktere obsahuje popis - defaultne je to "value" */
    var $valueFieldName;

    /** @var Option[]|object[] $data   Pole hodnot */
    var $data;

    /** @var ICreateItem */
    var $createItemInterface = null;

    /**
     * @param {Option[]|string[]|object[]} $data  muze to byt pole objektu Option, nebo jinych objektu, nebo asociativni pole stringu
     * @param string $keyFieldName
     * @param string $valueFieldName
     */
    function __construct($data = null, $keyFieldName = 'key', $valueFieldName = 'value')
    {
        $this ->keyFieldName = $keyFieldName;
        $this ->valueFieldName = $valueFieldName;

        if (isset($data)) {
            if (count($data)  &&  !(is_object(reset($data)))) {
                $this ->data = [];
                $this ->loadArray($data);
            } else {
                $this ->data = $data;
            }
        } else {
            $this ->data = [];
        }
    }


    /**
     * @param string[] $array
     * @return Options
     */
    function loadArray($array)
    {
        foreach ($array as $key => $value) {
            $this ->data[] = new Option($key, $value);
        }

        return $this;
    }


    /**
     * @param Option|object $option
     */
    function addOption($option)
    {
        $this ->data[] = $option;
    }

    /**
     * Najde zadanou hodnotu v datech
     * @param mixed $key
     * @param bool $dataTypeComparison
     * @return null|Option
     */
    function findOption($key, $dataTypeComparison = true)
    {
        foreach ($this ->data as $option) {
            if ($key !== ''  &&  $option ->{$this ->keyFieldName} === '') {
                $equalValue = false;
            } else {
                $equalValue = $dataTypeComparison ? ($key === $option->{$this->keyFieldName}) : ($key == $option->{$this->keyFieldName});
            }

            if ($equalValue) {
                return $option;
            }
        }



        return null;
    }


    function addOptions($newOptions)
    {
        $this ->data = array_merge($this ->data, $newOptions);
        return $this;
    }


    /**
     * Nacte polozky ze zadaneho dotazu. Nezrusi polozky, ktere uz v seznamu jsou. Vraci $this
     * Pokud je potreba slozitejsi nacitani, pouzijte tridu OptionLoader.
     * @param Database $database
     * @param string|SqlStatement $sql
     * @param Parameters $sqlParams
     * @param int $keyIndex         Index pole s klicem v sql dotazu
     * @param int $captionIndex     Index pole s hodnotou v sql dotazu
     * @return Options
     */
    function loadSQL($database, $sql, $sqlParams, $keyIndex = 0, $captionIndex = 1)
    {
        $newData = Option::loadSQL($database, $sql, $sqlParams, $keyIndex, $captionIndex);
        $this ->addOptions($newData);
        return $this;
    }


    /**
     * @param Database      $database
     * @param string|SqlStatement $sql
     * @param Parameters    $sqlParams
     * @param ICreateItem   $createItemInterface
     * @return array
     */
    function loadSQLCustomCreate($database, $sql, $sqlParams, $createItemInterface)
    {
        $newData = Option::loadSQLCustomCreate($database, $sql, $sqlParams, $createItemInterface);
        $this ->addOptions($newData);
        return $this;
    }
}
